summaryrefslogtreecommitdiff
path: root/bfd/reloc16.c
diff options
context:
space:
mode:
authorAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
committerAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
commitd9ec26b6578cfde9d7fb605787c9878ccd623893 (patch)
tree20a6a8bcbbf4b7822c06138f1ea37e335a09d5be /bfd/reloc16.c
parent0a693b807e2990a20fcdc75692dd1f1ecd355be0 (diff)
downloadbinutils-redhat-d9ec26b6578cfde9d7fb605787c9878ccd623893.tar.gz
Correct spelling of "relocatable".
Diffstat (limited to 'bfd/reloc16.c')
-rw-r--r--bfd/reloc16.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/bfd/reloc16.c b/bfd/reloc16.c
index 39f36e7b11..3a4c3d3c93 100644
--- a/bfd/reloc16.c
+++ b/bfd/reloc16.c
@@ -1,6 +1,6 @@
/* 8 and 16 bit COFF relocation functions, for BFD.
Copyright 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1998, 2000, 2001,
- 2002 Free Software Foundation, Inc.
+ 2002, 2003 Free Software Foundation, Inc.
Written by Cygnus Support.
This file is part of BFD, the Binary File Descriptor library.
@@ -240,13 +240,13 @@ bfd_coff_reloc16_get_relocated_section_contents (in_abfd,
link_info,
link_order,
data,
- relocateable,
+ relocatable,
symbols)
bfd *in_abfd;
struct bfd_link_info *link_info;
struct bfd_link_order *link_order;
bfd_byte *data;
- bfd_boolean relocateable;
+ bfd_boolean relocatable;
asymbol **symbols;
{
/* Get enough memory to hold the stuff. */
@@ -259,11 +259,11 @@ bfd_coff_reloc16_get_relocated_section_contents (in_abfd,
if (reloc_size < 0)
return NULL;
- /* If producing relocateable output, don't bother to relax. */
- if (relocateable)
+ /* If producing relocatable output, don't bother to relax. */
+ if (relocatable)
return bfd_generic_get_relocated_section_contents (in_abfd, link_info,
link_order,
- data, relocateable,
+ data, relocatable,
symbols);
/* Read in the section. */